from setuptools import setup

setup(
    name="opendas",
    version="0.1.0",
    long_description="OpenDAS",
    long_description_content_type="text/markdown",
    packages=["opendas"],
    install_requires=["numpy",  "h5py", "matplotlib", "pandas"],
)
